==> XOOPS-Core-XOOPS2.0-518a8ca.zip: XOOPS-Core-XOOPS2.0-518a8ca/XOOPS2.0/euc/modules/system/language/japanese/admin/blocksadmin.php <==
<?php
// $Id: blacksadmin.php 2008-07-23T16:04+09:00 2 8 6 $
//%%%%%%	Admin Module Name  Blocks 	%%%%%
define("_AM_DBUPDATED",_MD_AM_DBUPDATED);

//%%%%%%	blocks.php 	%%%%%
define("_AM_BADMIN","֥å");
define("_AM_ADDBLOCK","֥å");
define("_AM_LISTBLOCK","ƤΥ֥åɽ");
define("_AM_SIDE","ɽ");
define("_AM_BLKDESC","֥å");
define("_AM_TITLE","ȥ");
define("_AM_WEIGHT","¤ӽ");
define("_AM_ACTION","");
define("_AM_BLKTYPE","֥åΥ");
define("_AM_LEFT","¦");
define("_AM_RIGHT","¦");
define("_AM_CENTER","");
define("_AM_VISIBLE","ɽ / ɽ");
define("_AM_POSCONTT","ɲåƥĤ");
define("_AM_ABOVEORG","ΥƥĤξ");
define("_AM_AFTERORG","ΥƥĤβ");
define("_AM_EDIT","Խ");
define("_AM_DELETE","");
define("_AM_SBLEFT","ɥ֥å - ");
define("_AM_SBRIGHT","ɥ֥å - ");
define("_AM_CBLEFT","֥å - ");
define("_AM_CBRIGHT","֥å - ");
define("_AM_CBCENTER","֥å - ");
define("_AM_CBBOTTOMLEFT","֥å - ");
define("_AM_CBBOTTOMRIGHT","֥å - ");
define("_AM_CBBOTTOM","֥å - ");
define("_AM_CONTENT","ƥ");
define("_AM_OPTIONS","ץ");
define("_AM_CTYPE","ƥĤΥ");
define("_AM_HTML","HTML");
define("_AM_PHP","PHPץ");
define("_AM_AFWSMILE","ưեޥåȡʴ饢ͭ");
define("_AM_AFNOSMILE","ưեޥåȡʴ饢̵");
define("_AM_SUBMIT","");
define("_AM_CUSTOMHTML","HTML");
define("_AM_CUSTOMPHP","PHP");
define("_AM_CUSTOMSMILE","ʴ饢̵");
define("_AM_CUSTOMNOSMILE","ʴ饢̵");
define("_AM_DISPRIGHT","֥åΤɽ");
define("_AM_SAVECHANGES","ѹ¸");
define("_AM_EDITBLOCK","֥åԽ");
define("_AM_SYSTEMCANT","ƥ֥åϺǤޤ");
define("_AM_MODULECANT","Υ֥åľܺ뤳ȤϤǤޤˤΥ֥åΥ⥸塼󥢥ƥ֤ˤƤ");
define("_AM_RUSUREDEL","<b>%s</b>֥å˺Ƥ⤤Ǥ");
define("_AM_NAME","̾");
define("_AM_USEFULTAGS","Ѳǽʥ");
define("_AM_BLOCKTAG1","%s  %s ɽޤ");
define('_AM_SVISIBLEIN', 'ɽ̡ %s ');//Show blocks visible in %s');
define('_AM_TOPPAGE', 'ȥåץڡ');
define('_AM_VISIBLEIN', 'ɽ');
define('_AM_ALLPAGES', '٤ƤΥڡ');
define('_AM_TOPONLY', 'ȥåץڡΤ');
define('_AM_ADVANCED', '٤');
define('_AM_BCACHETIME', 'åμ̿');
define('_AM_BALIAS', 'ꥢ̾');
define('_AM_CLONE', 'ʣ');  // clone a block
define('_AM_CLONEBLK', 'ʣ'); // cloned block
define('_AM_CLONEBLOCK', 'ʣ֥åκ');
define('_AM_NOTSELNG', "'%s' 򤵤Ƥޤ!"); // error message
define('_AM_EDITTPL', 'ƥץ졼ȤԽ');
define('_AM_MODULE', '⥸塼');
define('_AM_GROUP', '롼');
define('_AM_UNASSIGNED', '̤');

?>

==> XOOPS-Core-XOOPS2.4-518a8ca.zip: XOOPS-Core-XOOPS2.4-518a8ca/XOOPS2.4/euc/modules/system/language/japanese/admin/blocksadmin.php <==
<?php
// $Id: blocksadmin.php $
// _LANGCODE: ja
// _CHARSET : EUC-JP
// Translator: XOOPS Translation Team

//%%%%%%	Admin Module Name  Blocks 	%%%%%
define("_AM_DBUPDATED",_MD_AM_DBUPDATED);

//%%%%%%	blocks.php 	%%%%%
define("_AM_BADMIN","֥å");
define("_AM_ADDBLOCK","֥åɲ");
define("_AM_LISTBLOCK","٤ƤΥ֥åɽ");
define("_AM_SIDE","ɽ");
define("_AM_BLKDESC","֥å");
define("_AM_TITLE","ȥ");
define("_AM_WEIGHT","¤ӽ");
define("_AM_ACTION","");
define("_AM_BLKTYPE","֥åΥ");
define("_AM_LEFT","");
define("_AM_RIGHT","");
define("_AM_CENTER","");
define("_AM_VISIBLE","ɽ / ɽ");
define("_AM_POSCONTT","ɲåƥĤ");
define("_AM_ABOVEORG","ΥƥĤξ");
define("_AM_AFTERORG","ΥƥĤβ");
define("_AM_EDIT","Խ");
define("_AM_DELETE","");
define("_AM_SBLEFT","ɥ֥å - ");
define("_AM_SBRIGHT","ɥ֥å - ");
define("_AM_CBLEFT","֥å - ");
define("_AM_CBRIGHT","֥å - ");
define("_AM_CBCENTER","֥å - ");
define("_AM_CBBOTTOMLEFT","֥å - ");
define("_AM_CBBOTTOMRIGHT","֥å - ");
define("_AM_CBBOTTOM","֥å - ");
define("_AM_CONTENT","ƥ");
define("_AM_OPTIONS","ץ");
define("_AM_CTYPE","ƥĤΥ");
define("_AM_HTML","HTML ");
define("_AM_PHP","PHP ץ");
define("_AM_AFWSMILE","ưեޥåȡʴʸͭ");
define("_AM_AFNOSMILE","ưեޥåȡʴʸ̵");
define("_AM_SUBMIT","");
define("_AM_CUSTOMHTML","֥å(HTML)");
define("_AM_CUSTOMPHP","֥å(PHP)");
define("_AM_CUSTOMSMILE","֥å(ʸͭ)");
define("_AM_CUSTOMNOSMILE","֥å(ʸ̵)");
define("_AM_DISPRIGHT","֥åΤɽ");
define("_AM_SAVECHANGES","ѹ¸");
define("_AM_EDITBLOCK","֥åԽ");
define("_AM_SYSTEMCANT","ƥ֥åϺǤޤ");
define("_AM_MODULECANT","Υ֥åľܺǤޤ󡪥֥åɽˤϥ⥸塼̵ꤷƤ");
define("_AM_RUSUREDEL","˺Ƥ⤤Ǥ: ֥å <strong>%s</strong>");
define("_AM_NAME","̾");
define("_AM_USEFULTAGS","Ȥ륿:");
define("_AM_BLOCKTAG1","%s  %s ɽޤ");
define('_AM_SVISIBLEIN', 'ɽ̡ %s ');//Show blocks visible in %s');
define('_AM_TOPPAGE', 'ȥåץڡ');
define('_AM_VISIBLEIN', 'ɽ');
define('_AM_ALLPAGES', 'ڡ');
define('_AM_TOPONLY', 'ȥåץڡΤ');
define('_AM_ADVANCED', '٤');
define('_AM_BCACHETIME', 'Cache ');
define('_AM_BALIAS', '̾');
define('_AM_CLONE', 'ʣ');  // clone a block
define('_AM_CLONEBLK', 'ʣ'); // cloned block
define('_AM_CLONEBLOCK', 'ʣ֥åκ');
define('_AM_NOTSELNG', "'%s' 򤵤Ƥޤ!"); // error message
define('_AM_EDITTPL', 'ƥץ졼Խ');
define('_AM_MODULE', '⥸塼');
define('_AM_GROUP', '롼');
define('_AM_UNASSIGNED', '̤');

define("_AM_CUSTOM","֥å");
define('_AM_GENERATOR', '֥å: %s');
define('_AM_TYPES', '');

?>
